/// <reference types="node" resolution-mode="require"/>
export { log } from 'node:console';
export { clsx } from 'clsx';
export { default as jsonLoose } from 'json-loose';
export { isString, isNil, isNull } from 'lodash-es';
/**
 * Checks if a variable is considered enabled.
 *
 * @param input - The variable to be checked for enablement.
 * @returns
 *   `true` if the variable is strictly equal to `true` or an empty string (`''`),
 *   indicating enablement. Otherwise, returns `false`.
 */
export declare function isEnabled(input: unknown): boolean;
/**
 * Normalize the breakpoint prop by appending it to the prefix.
 *
 * @param prefix The prefix string.
 * @param prop The breakpoint prop string or an array of strings.
 * @returns The normalized class name string.
 */
export declare function normalizeBreakpointProp(prefix: string, prop: string | boolean | Array<string | boolean>): string;
/**
 * Checks if the input is boolean-like.
 *
 * @param input - The value to check for boolean likeness.
 * @returns
 *   `true` if the input is a boolean or a string with value 'true' or 'false',
 *   otherwise `false`.
 */
export declare function isBooleanLike(input: unknown): boolean;
/**
 * Checks if the input is truthy.
 *
 * @param input - The value to check for truthiness.
 * @returns `true` if the value is truthy, otherwise `false`.
 */
export declare function isTruthy(input: unknown): boolean;
/**
 * Checks if the input is falsy.
 *
 * @param input - The value to check for falsiness.
 * @returns `true` if the value is falsy, otherwise `false`.
 */
export declare function isFalsy(input: unknown): boolean;
